@@ -82,19 +82,19 @@ execute()
 
 	# Run the command
 	case "$profile" in 
-		"0" ) 	ffmpeg2theora -f dv --cropleft 8 --cropright 8 --optimize -v 10 -a 10 \
+		"0" ) 	ffmpeg2theora -f dv --optimize -v 10 -S 2 -a 10 \
 				--title "$title" --artist "$artist" --location "$location" --copyright "$copyright" \
 				-o "$file".ogg - ;;
-		"1" ) 	ffmpeg2theora -f dv -x $full_res_x -y $full_res_y --cropleft 8 --cropright 8 --optimize -v 7 -a 3 \
+		"1" ) 	ffmpeg2theora -f dv -x $full_res_x -y $full_res_y --optimize -v 7 -a 3 \
 				--title "$title" --artist "$artist" --location "$location" --copyright "$copyright" \
 				-o "$file".ogg - ;;
-		"2" ) 	ffmpeg2theora -f dv -x $med_res_x -y $med_res_y --cropleft 8 --cropright 8 --optimize -v 7 -a 3 -H 44100 \
+		"2" ) 	ffmpeg2theora -f dv -x $med_res_x -y $med_res_y --optimize -v 7 -a 3 -H 44100 \
 				--title "$title" --artist "$artist" --location "$location" --copyright "$copyright" \
 				-o "$file".ogg - ;;
-		"3" ) 	ffmpeg2theora -f dv -x $med_res_x -y $med_res_y --cropleft 8 --cropright 8 --optimize -v 5 -V 500 -K 200 -a 3 -A 64 -H 32000 \
+		"3" ) 	ffmpeg2theora -f dv -x $med_res_x -y $med_res_y --optimize -v 5 -V 500 -S 1 -K 200 -a 3 -A 64 -H 32000 \
 				--title "$title" --artist "$artist" --location "$location" --copyright "$copyright" \
 				-o "$file".ogg - ;;
-		"4" ) 	ffmpeg2theora -f dv -x $low_res_x -y $low_res_y --cropleft 8 --cropright 8 --optimize -v 1 -V 84 -K 300 -a 0 -A 44 -H 22050 \
+		"4" ) 	ffmpeg2theora -f dv -x $low_res_x -y $low_res_y --optimize -v 1 -V 84 -S 2 -K 200 -a 0 -A 44 -H 22050 \
 				--title "$title" --artist "$artist" --location "$location" --copyright "$copyright" \
 				-o "$file".ogg - ;;
 	esac
