@@ -61,7 +61,7 @@ execute()
 			ffmpeg -v 0 -f dv -i pipe: -f rawvideo -pix_fmt yuv420p pipe: \
 			-vn -f $audio_format -ac 2 -ab $audio_bitrate -ar 48000 -y "$AC3" | \
 			ffmpeg -v 0 -f rawvideo -pix_fmt yuv420p -s "$normalisation" -r "$normalisation" -i pipe: \
-			-an -target dvd -f mpeg2video -maxrate 8000$kilo $interlace -aspect $aspect -y "$M2V"
+			-an -threads $threads -target dvd -f mpeg2video -maxrate 8000$kilo $interlace -aspect $aspect -y "$M2V"
 			mplex -v 0 -f 8 -o "$file".vob "$M2V" "$AC3"
 			;;
 		"1" )
@@ -72,7 +72,7 @@ execute()
 			ffmpeg -v 0 -f dv -i pipe: -f rawvideo -pix_fmt yuv420p pipe: \
 			-vn -f $audio_format -ac 2 -ab $audio_bitrate -ar 48000 -y "$AC3" | \
 			ffmpeg -v 0 -f rawvideo -pix_fmt yuv420p -s "$normalisation" -r "$normalisation" -i pipe: \
-			-an -target dvd -f mpeg2video -maxrate 8000$kilo $interlace -aspect $aspect -y "$M2V"
+			-an -threads $threads -target dvd -f mpeg2video -maxrate 8000$kilo $interlace -aspect $aspect -y "$M2V"
 			mplex -v 0 -f 8 -o "$VOB" "$M2V" "$AC3" &
 
 			XML=`mktemp $file-dvdauthor.XXXXXX`
