@@ -57,7 +57,7 @@ execute()
 	# Run the command
 	case "$profile" in 
 		"0" ) ffmpeg -threads $threads -f dv -i pipe: -pass $pass -passlogfile "$file" \
-			-vcodec $x264 -g 300 $hq $itnerlace -aspect $aspect -b 2048$kilo -ab 192$audio_kilo \
+			-vcodec $x264 -g 300 $hq $interlace -aspect $aspect -b 2048$kilo -ab 192$audio_kilo \
 			-title "$title" -author "$author" -comment "$comment" -copyright "$copyright" \
 			-y "$file".mp4 ;;
 		"1" ) ffmpeg -threads $threads -f dv -i pipe: -pass $pass -passlogfile "$file" \
