@@ -49,23 +49,23 @@ execute()
 	
 	# Run the command
 	case "$profile" in 
-		"0" ) 	ffmpeg -f dv -i pipe: -pass $pass -passlogfile "$file" \
+		"0" ) 	ffmpeg -threads $threads -f dv -i pipe: -pass $pass -passlogfile "$file" \
 			-g 300 $hq $interlace -aspect $aspect -b 2048$kilo -ab 192$audio_kilo \
 			-title "$title" -author "$author" -comment "$comment" -copyright "$copyright" \
 			-y "$file".mp4 ;;
-		"1" ) 	ffmpeg -f dv -i pipe: -pass $pass -passlogfile "$file" \
+		"1" ) 	ffmpeg -threads $threads -f dv -i pipe: -pass $pass -passlogfile "$file" \
 			-g 300 $hq $progressive -s $full_res -aspect $aspect -b 2048$kilo -ab 192$audio_kilo \
 			-title "$title" -author "$author" -comment "$comment" -copyright "$copyright" \
 			-y "$file".mp4 ;;
-		"2" ) 	ffmpeg -f dv -i pipe: -pass $pass -passlogfile "$file" \
+		"2" ) 	ffmpeg -threads $threads -f dv -i pipe: -pass $pass -passlogfile "$file" \
 			-g 300 $hq $progressive -s $med_res -aspect $aspect -b 1024$kilo -ab 128$audio_kilo -ar 44100 \
 			-title "$title" -author "$author" -comment "$comment" -copyright "$copyright" \
 			-y "$file".mp4 ;;
-		"3" ) 	ffmpeg -f dv -i pipe: -pass $pass -passlogfile "$file" \
+		"3" ) 	ffmpeg -threads $threads -f dv -i pipe: -pass $pass -passlogfile "$file" \
 			-g 300 $hq $progressive -s $med_res -aspect $aspect -b 500$kilo -g 60 -ab 64$audio_kilo -ar 32000 \
 			-title "$title" -author "$author" -comment "$comment" -copyright "$copyright" \
 			-y "$file".mp4 ;;
-		"4" ) 	ffmpeg -f dv -i pipe: -pass $pass -passlogfile "$file" \
+		"4" ) 	ffmpeg -threads $threads -f dv -i pipe: -pass $pass -passlogfile "$file" \
 			$hq -r 12 -g 120 $progressive -s $low_res -aspect $aspect -b 96$kilo -ac 1 -ab 32$audio_kilo -ar 22050 \
 			-title "$title" -author "$author" -comment "$comment" -copyright "$copyright" \
 			-y "$file".mp4 ;;
