@@ -17,9 +17,10 @@ if [ "$1" != "--usage" ] && [ "x$1" != "x" ]; then
 	[ `echo $ffmpeg_formats | egrep "(Encoders:)|(.*EV.*libmp3lame)" | wc -l` -gt 0 ] && mp3="libmp3lame"
 	
 	test_mv4=`echo $ffmpeg_help | grep 'mv4' | wc -l`
-	interlace=`[ "$test_mv4" -gt 0 ] && echo "-ildct 1 -ilme 1" || echo "-ildct -ilme"`
+	test_flags=`echo $ffmpeg_help | grep '\-flags' | wc -l`
+	interlace=`[ "$test_flags" -gt 0 ] && echo "-flags +ildct+ilme" || ( [ "$test_mv4" -gt 0 ] && echo "-ildct 1 -ilme 1" || echo "-ildct -ilme" )`
 	progressive="-deinterlace"
-	threads=`cat /proc/cpuinfo 2> /dev/null | grep -c processor`
+	threads=`cat /proc/cpuinfo 2> /dev/null | egrep -c 'processor[[:space:]]*:[[:space:]][0-9]'`
 	
 	if [ "$aspect" = "16:9" ]; then
 		full_res=`[ "$normalisation" = "pal" ] && echo "1024x576" || echo "854x480"`
@@ -41,7 +42,7 @@ ffmpeg_generate_hq()
 	qpel="-qpel"
 	[ "$test_4mv" -gt 0 ] && hq="$hq -4mv"
 	if [ "$test_mv4" -gt 0 ]; then
-		hq="$hq -mv4 1"
-		qpel="-qpel 1"
+		hq="$hq -flags +mv4"
+		qpel="-flags +qpel"
 	fi
 }
