@@ -544,12 +544,22 @@ bool Frame::GetTimeCode( TimeCode &timeCode ) const
 #ifdef HAVE_LIBDV
 	int timestamp[ 4 ];
 
-	dv_get_timestamp_int( decoder, timestamp );
-
-	timeCode.hour = timestamp[ 0 ];
-	timeCode.min = timestamp[ 1 ];
-	timeCode.sec = timestamp[ 2 ];
-	timeCode.frame = timestamp[ 3 ];
+	if ( dv_get_timestamp_int( decoder, timestamp ) )
+	{
+		timeCode.hour = timestamp[ 0 ];
+		timeCode.min = timestamp[ 1 ];
+		timeCode.sec = timestamp[ 2 ];
+		timeCode.frame = timestamp[ 3 ];
+		return true;
+	}
+	else
+	{
+		timeCode.hour = 0;
+		timeCode.min = 0;
+		timeCode.sec = 0;
+		timeCode.frame = 0;
+		return false;
+	}
 #else
 
 	Pack tc;
@@ -1330,6 +1340,9 @@ bool Frame::CreateEncoder( bool isPAL, bool isWide )
 				else
  					avcodecEncoder->sample_aspect_ratio = isWide ? ( AVRational ){ 40, 33 } : ( AVRational ){ 10, 11 };
 			}
+#if LIBAVFORMAT_VERSION_INT >= ((52<<16)+(21<<8)+0)
+			vst->sample_aspect_ratio = avcodecEncoder->sample_aspect_ratio;
+#endif
 			avcodecEncoder->thread_count = 2;
 			avcodec_thread_init( avcodecEncoder, avcodecEncoder->thread_count );
 			avcodecEncoder->time_base= isPAL ? ( AVRational ){ 1, 25 } : ( AVRational ){ 1001, 30000 };
@@ -1494,19 +1507,25 @@ class KinoFramePool : public FramePool
 private:
 	// The list of available frames
 	deque < Frame* > frames;
+	pthread_mutex_t mutex;
 
 public:
 	KinoFramePool( )
-	{}
+	{
+		pthread_mutex_init( &mutex, NULL );
+	}
 
 	virtual ~KinoFramePool( )
 	{
+		pthread_mutex_lock( &mutex );
 		for ( int i = frames.size( ); i > 0; --i )
 		{
 			Frame *frame = frames[ 0 ];
 			frames.pop_front( );
 			delete frame;
 		}
+		pthread_mutex_unlock( &mutex );
+		pthread_mutex_destroy( &mutex );
 	}
 
 	Frame *GetFrame( )
@@ -1519,7 +1538,9 @@ public:
 		else
 		{
 			frame = frames[ 0 ];
+			pthread_mutex_lock( &mutex );
 			frames.pop_front( );
+			pthread_mutex_unlock( &mutex );
 		}
 		frame->SetPreferredQuality( );
 		return frame;
@@ -1527,7 +1548,9 @@ public:
 
 	void DoneWithFrame( Frame *frame )
 	{
+		pthread_mutex_lock( &mutex );
 		frames.push_back( frame );
+		pthread_mutex_unlock( &mutex );
 	}
 };
 
